bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments.__init__
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaMoments.__init__